# Dnxmy: Dummy Data for Machine Learning and Statistics
[![PyPI Version](https://img.shields.io/pypi/v/dnxmy.svg)](https://pypi.org/project/dnxmy/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Python module for creating dummy data sets for testing machine learning and statistical analysis.

![logo](https://user-images.githubusercontent.com/64354512/229360901-92ef0eb3-3ce0-46fe-bb55-37942a775b81.png)

## Usage
### Requirements
Tested in the following environments.

- Python 3.6 or higher
- Numpy 1.22.4 or higher
- Pandas 1.4.4 or higher

### Installation
Use pip to install the binary wheels on PyPI.
```bash 
$ pip install dnxmy
```

### Import

```python
import dnxmy
```

### Example
The following notebook is a reference case study using this library.

- [Example]()

## Support
Bugs may be reported at [issues](https://github.com/roseiricho/dnxmy/issues).

## License
This project is licensed under the MIT License - see the [LICENSE](https://github.com/roseiricho/dnxmy/blob/main/LICENSE) file for details.

## Documentation
The documentation is available at [docs](https://roseiricho.github.io/dnxmy/dnxmy.html#).